summaryrefslogtreecommitdiffstats
path: root/src/selection.h
diff options
context:
space:
mode:
authorEric Greveson <eric@greveson.co.uk>2013-07-04 14:01:44 +0000
committerEric Greveson <eric@greveson.co.uk>2013-07-04 14:01:44 +0000
commit104efe4e3ecadc975ab76748c66f041abf8ee7b1 (patch)
tree01c6a23e2ee0bf43fda8eb78441a34e9dc338a3b /src/selection.h
parentMerge recent changes from inkscape trunk (diff)
downloadinkscape-104efe4e3ecadc975ab76748c66f041abf8ee7b1.tar.gz
inkscape-104efe4e3ecadc975ab76748c66f041abf8ee7b1.zip
Code readability improvements and licence changes for action-context.*
based on merge request code review and feedback (bzr r12387.1.7)
Diffstat (limited to '')
-rw-r--r--src/selection.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/selection.h b/src/selection.h
index 65a6c5140..f076cf7aa 100644
--- a/src/selection.h
+++ b/src/selection.h
@@ -67,10 +67,10 @@ public:
* Constructs an selection object, bound to a particular
* layer model
*
* @param layer_model the layer model (for the SPDesktop, if GUI)
* @param desktop the desktop associated with the layer model, or NULL if in console mode
*/
- Selection(LayerModel *layer_model, SPDesktop *desktop);
+ Selection(LayerModel *layers, SPDesktop *desktop);
~Selection();
/**
@@ -79,7 +79,7 @@ public:
* @return the layer model the selection is bound to, which is the same as the desktop
* layer model for GUI mode
*/
- LayerModel *layerModel() { return _layer_model; }
+ LayerModel *layers() { return _layers; }
/**
* Returns the desktop the selection is bound to
@@ -352,7 +352,7 @@ private:
std::list<SPBox3D *> _3dboxes;
- LayerModel *_layer_model;
+ LayerModel *_layers;
GC::soft_ptr<SPDesktop> _desktop;
SPObject* _selection_context;
guint _flags;
@@ -67,10 +67,10 @@ public:
* layer model
*
- * @param layer_model the layer model (for the SPDesktop, if GUI)
+ * @param layers the layer model (for the SPDesktop, if GUI)
* @param desktop the desktop associated with the layer model, or NULL if in console mode
*/